Http class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

all(String path, HttpHandler handler) → void
delete(String path, HttpHandler handler) → void
get(String path, HttpHandler handler) → void
listen() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(String path, HttpHandler handler) → void
post(String path, HttpHandler handler) → void
put(String path, HttpHandler handler) → void
toString() → String
A string representation of this object.
inherited
use(HttpHandler handler) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

createServer({String host = 'localhost', int port = 8080}) → Future<Http>