Request class

Constructors

Request(HttpRequest raw, {Map<String, String> params = const {}})

Properties

body ↔ dynamic
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
method → String
no setter
params → Map<String, String>
final
path → String
no setter
query ↔ Map<String, String>
latefinal
raw → HttpRequest
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
no setter

Methods

json() → Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
text() → Future<String>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited