Response class

Constructors

Response(HttpResponse _raw)

Properties

ended → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

end([String? data]) → void
json(Object? data, {int? statusCode}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(Object? data, {int? statusCode}) → void
setHeader(String name, String value) → Response
status(int code) → Response
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited