Route class

Constructors

Route({required String method, required String path, required HttpHandler handler})

Properties

handler → HttpHandler
final
hashCode → int
The hash code for this object.
no setterinherited
method → String
final
path → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

extractParams(String path) → Map<String, String>
match(String method, String path) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited