Socket class

Constructors

Socket(WebSocket _ws)

Properties

data → Map<String, dynamic>
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

disconnect([int? code, String? reason]) → Future<void>
emit(String event, [dynamic data]) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
off(String event, [SocketHandler? handler]) → void
on(String event, SocketHandler handler) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited