SocketClient class

Constructors

SocketClient({String host = '127.0.0.1', int port = 4040})

Properties

hashCode → int
The hash code for this object.
no setterinherited
host → String
final
port → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect() → Future<void>
disconnect() → Future<void>
emit(String event, [dynamic data]) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, SocketEventHandler handler) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited