SocketServer class

Constructors

SocketServer({String host = '0.0.0.0', int port = 4040})

Properties

hashCode → int
The hash code for this object.
no setterinherited
host → String
final
port → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

broadcast(String event, [dynamic data]) → void
broadcastExcept(Socket except, String event, [dynamic data]) → void
emit(Socket client, String event, [dynamic data]) → void
listen() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, SocketEventHandler handler) → void
onConnection(SocketConnectionHandler handler) → void
onDisconnect(SocketConnectionHandler handler) → void
stop() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited