River class
Constructors
- River()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createCli(
List< String> args, {String name = 'app', String version = '1.0.0'}) → Cli -
createHttpServer(
{String host = 'localhost', int port = 8080}) → Future< Http> -
createSocketServer(
) → SocketServer