SocketServer class

Constructors

SocketServer()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → Future<void>
emit(String event, [dynamic data]) → void
emitExcept(Socket except, String event, [dynamic data]) → void
join(Socket socket, String room) → void
leave(Socket socket, String room) → void
listen(int port, {String host = 'localhost', String path = '/ws'}) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, SocketHandler handler) → void
onConnection(SocketConnectionHandler handler) → void
onDisconnect(SocketConnectionHandler handler) → void
to(String room, String event, [dynamic data]) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited